==> lumina-1.2.0.tar.gz: lumina-1.2.0/src-qt5/desktop-utils/lumina-fileinfo/i18n/l-fileinfo_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <location filename="../MainUI.ui" line="24"/>
        <location filename="../MainUI.cpp" line="97"/>
        <source>File Information</source>
        <translation>Information Fichier</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="56"/>
        <source>Owner:</source>
        <translation>Propriétaire:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="73"/>
        <source>Group:</source>
        <translation>Groupe:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="90"/>
        <source>Permissions:</source>
        <translation>Permissions:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="104"/>
        <source>Created:</source>
        <translation>Créé le:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="111"/>
        <source>Note: The time a file was created might be more recent than the time modified if the file permissions were changed recently.</source>
        <translation>Note: La date à laquelle un fichier est créé peut être plus récente que la date de modification si les permissions du fichier ont été modifiées récemment.</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Last Modified:</source>
        <translation>Dernière modification:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="131"/>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="138"/>
        <source>MimeType:</source>
        <translation>Type MIME:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="185"/>
        <source>File Size:</source>
        <translation>Taille du fichier:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="216"/>
        <location filename="../MainUI.cpp" line="140"/>
        <source>Edit Shortcut</source>
        <translation>Modifier le racourci</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="239"/>
        <source>Working Dir:</source>
        <translation>Répertoire de travail:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="246"/>
        <source>Use startup notification</source>
        <translation>Utiliser les notifications de démarrage</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="260"/>
        <source>Icon:</source>
        <translation>Icone:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="267"/>
        <source>Command:</source>
        <translation>Commande:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="274"/>
        <source>Comment:</source>
        <translation>Commentaire:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="284"/>
        <source>Run in terminal</source>
        <translation>Executer dans un terminal:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="291"/>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="336"/>
        <source>No Icon</source>
        <translation>Pas d&apos;icône</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="392"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="405"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="61"/>
        <source>---Calculating---</source>
        <translation>---En cours de calcul---</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="70"/>
        <source>Read/Write</source>
        <translation>Lecture/Ecriture</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="71"/>
        <source>Read Only</source>
        <translation>Lecture seule</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="72"/>
        <source>Write Only</source>
        <translation>Ecriture seule</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="73"/>
        <source>No Access</source>
        <translation>Aucun accès</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="77"/>
        <source>XDG Shortcut</source>
        <translation>Raccourci XDG</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="78"/>
        <source>Directory</source>
        <translation>Répertoire</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="79"/>
        <source>Binary</source>
        <translation>Binaire</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="81"/>
        <source>Hidden %1</source>
        <translation>Caché %1</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="126"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="249"/>
        <source>Save Application File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="249"/>
        <source>Application Registrations (*.desktop)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="290"/>
        <source>Select a binary</source>
        <translation>Choisir un binaire</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="293"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="293"/>
        <source>Invalid selection: Not a valid executable</source>
        <translation>Sélection invalide: Ce n&apos;est pas un exécutable valide</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="305"/>
        <source>Select a directory</source>
        <translation>Sélectionner un répertoire</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="318"/>
        <source>Select an icon</source>
        <translation>Sélectionner une icône</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="318"/>
        <source>Images (%1);; All Files (*)</source>
        <translation>Images (%1);; Tous les fichiers (*)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="341"/>
        <location filename="../MainUI.cpp" line="343"/>
        <source> Folders: </source>
        <translation> Répertoires: </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="341"/>
        <location filename="../MainUI.cpp" line="343"/>
        <source>Files: </source>
        <translation>Fichiers:</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="343"/>
        <source>  Calculating...</source>
        <translation>  En cours de calcul...</translation>
    </message>
</context>
</TS>

==> lumina-1.3.0_p1.tar.gz: lumina-1.3.0-p1/src-qt5/desktop-utils/lumina-fileinfo/i18n/l-fileinfo_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <location filename="../MainUI.ui" line="24"/>
        <location filename="../MainUI.cpp" line="96"/>
        <source>File Information</source>
        <translation>Information Fichier</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="56"/>
        <source>Owner:</source>
        <translation>Propriétaire :</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="73"/>
        <source>Group:</source>
        <translation>Groupe :</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="90"/>
        <source>Permissions:</source>
        <translation>Permissions :</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="104"/>
        <source>Created:</source>
        <translation>Créé le:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="111"/>
        <source>Note: The time a file was created might be more recent than the time modified if the file permissions were changed recently.</source>
        <translation>Note : La date de création peut être plus récente que la date de modification si les permissions du fichier ont été modifiées récemment.</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Last Modified:</source>
        <translation>Dernière Modification :</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="131"/>
        <source>Type:</source>
        <translation>Type :</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="138"/>
        <source>MimeType:</source>
        <translation>Type MIME :</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="185"/>
        <source>File Size:</source>
        <translation>Taille du Fichier :</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="216"/>
        <location filename="../MainUI.cpp" line="139"/>
        <source>Edit Shortcut</source>
        <translation>Modifier le Raccourci</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="239"/>
        <source>Working Dir:</source>
        <translation>Dossier de Travail :</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="246"/>
        <source>Use startup notification</source>
        <translation>Utiliser les notifications de démarrage</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="260"/>
        <source>Icon:</source>
        <translation>Icône :</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="267"/>
        <source>Command:</source>
        <translation>Commande :</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="274"/>
        <source>Comment:</source>
        <translation>Commentaire :</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="284"/>
        <source>Run in terminal</source>
        <translation>Exécuter dans un terminal</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="291"/>
        <source>Name:</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="336"/>
        <source>No Icon</source>
        <translation>Pas d&apos;Icône</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="392"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="405"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="60"/>
        <source>---Calculating---</source>
        <translation>---En cours de calcul---</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="69"/>
        <source>Read/Write</source>
        <translation>Lecture/Ecriture</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="70"/>
        <source>Read Only</source>
        <translation>Lecture Seule</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="71"/>
        <source>Write Only</source>
        <translation>Ecriture Seule</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="72"/>
        <source>No Access</source>
        <translation>Aucun Accès</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="76"/>
        <source>XDG Shortcut</source>
        <translation>Raccourci XDG</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="77"/>
        <source>Directory</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="78"/>
        <source>Binary</source>
        <translation>Binaire</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="80"/>
        <source>Hidden %1</source>
        <translation>Caché %1</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="125"/>
        <source>URL:</source>
        <translation>URL :</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="247"/>
        <source>Save Application File</source>
        <translation>Enregistrer le Fichier</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="247"/>
        <source>Application Registrations (*.desktop)</source>
        <translation>Lanceurs de Programmes (*.desktop)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="288"/>
        <source>Select a binary</source>
        <translation>Choisir un binaire</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="291"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="291"/>
        <source>Invalid selection: Not a valid executable</source>
        <translation>Sélection invalide : Ce n&apos;est pas un exécutable valide</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="303"/>
        <source>Select a directory</source>
        <translation>Sélectionner un dossier</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="316"/>
        <source>Select an icon</source>
        <translation>Sélectionner une icône</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="316"/>
        <source>Images (%1);; All Files (*)</source>
        <translation>Images (%1);; Tous les fichiers (*)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="339"/>
        <location filename="../MainUI.cpp" line="341"/>
        <source> Folders: </source>
        <translation> Dossiers : </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="339"/>
        <location filename="../MainUI.cpp" line="341"/>
        <source>Files: </source>
        <translation>Fichiers : </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="341"/>
        <source>  Calculating...</source>
        <translation>  En cours de calcul...</translation>
    </message>
</context>
</TS>
